@@ -10,6 +10,7 @@ function run_kernel()
     println(Core.stdout, "Starting kernel event loops.")
     kernel = Kernel()
     IJulia.init(ARGS, kernel)
+    isempty(ARGS) || popfirst!(ARGS) # Jupyter argument should not be visible to user
 
     let startupfile = !isempty(DEPOT_PATH) ? abspath(DEPOT_PATH[1], "config", "startup_ijulia.jl") : ""
         isfile(startupfile) && Base.JLOptions().startupfile != 2 && Base.include(Main, startupfile)
@@ -18,14 +19,6 @@ function run_kernel()
     # import things that we want visible in IJulia but not in REPL's using IJulia
     @eval Main import IJulia: ans, In, Out, clear_history
 
-    # check whether Revise is running and as needed configure it to run before every prompt
-    if isdefined(Main, :Revise)
-        if get(ENV, "JULIA_REVISE", "auto") == "auto"
-            IJulia.push_preexecute_hook(Main.Revise.revise)
-            kernel.revise_precompile_task[] = Threads.@spawn precompile(Main.Revise.revise, ())
-        end
-    end
-
     wait(kernel)
     close(kernel)
 end
